% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/replicatePlots.R
\name{artmsReplicatePlots}
\alias{artmsReplicatePlots}
\title{Create the replicate plots based on the pairings from
the replicate plot file}
\usage{
artmsReplicatePlots(input_file, keys_file, replicate_file, out_file,
  prot_exp = c("AB", "PH", "UB", "APMS"), verbose = TRUE)
}
\arguments{
\item{input_file}{(char) MaxQuant evidence file and location}

\item{keys_file}{(char) Keys file with the experimental details}

\item{replicate_file}{(char) Replicate file. Check Vignette for examples}

\item{out_file}{(char) Output .TEXT file with the intensity values of every
feature}

\item{prot_exp}{(char) Proteomics experiment. 4 options available:
\itemize{
\item \code{AB}: (default) protein abundance
\item \code{APMS}: affinity purification mass spectrometry
\item \code{PH}: protein phosphorylation
\item \code{UB}: protein ubiquitination (aka ubiquitylation)
}}

\item{verbose}{(logical) \code{TRUE} (default) shows function messages}
}
\value{
The output file of the summary of features and intensity values
}
\description{
Outputs a replicate plots based on a user provied file
containing the replicates to be compared. Values are based on the log2
value of the maximum intensities per modified sequence.
The "replicate file" should describe which replicates of which conditions
should be compared against each other. Each row represents a replicate
plot to be created. The file should be structured using the following
format and column names:\preformatted{**condition1**|**rep1\\_1**|**rep1\\_2**|**condition2**|**rep2\\_1**|**rep2\\_2**
-----|-----|-----|-----|-----|-----
Cal33|Cal33-1|Cal33-2|HSC6|HSC6-1|HSC6-2
Cal33|Cal33-3|Cal33-4|HSC6|HSC6-3|HSC6-4
}
}
\examples{
# First, let's make the "replicate file" (in a data.frame)
x_names <- c("condition1", "rep1_1", "rep1_2", "condition2", "rep2_1", 
"rep2_2")
x_values <- c("Cal33", "Cal33-1", "Cal33-4", "HSC6", "HSC6-2", "HSC6-3")
replica_info <- data.frame(t(x_values))
colnames(replica_info) <- x_names

# Now let's make the plots.
artmsReplicatePlots(input_file = artms_data_ph_evidence,
                     keys_file = artms_data_ph_keys,
                     replicate_file = replica_info,
                     out_file = NULL,
                     prot_exp = "PH")

# Remember that if you want to see the txt results and pdf file, just
# change out_file = NULL" to out_file = 'output_file.pdf'
}
\keyword{evidence,}
\keyword{plots}
\keyword{replica,}
